%define upstream_name    GD
%define upstream_version 2.78

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    A perl5 interface to Thomas Boutell's gd library
License:    Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/GD/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(ExtUtils::Constant) >= 0.220.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(ExtUtils::PkgConfig)
BuildRequires: perl(Math::Trig)
BuildRequires: perl(Test::Fork) >= 0.20.0
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(Test::NoWarnings) >= 1.0.0
BuildRequires: freetype-devel
BuildRequires: pkgconfig(gdlib)
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(libpng)
BuildRequires: perl-devel
BuildRequires: pkgconfig(xpm)
BuildRequires: pkgconfig(zlib)
%{?perl_default_filter}

%description
GD.pm is a autoloadable interface module for libgd, a popular library
for creating and manipulating PNG files.  With this library you can
create PNG images on the fly or modify existing files.  Features
include:

a.  lines, polygons, rectangles and arcs, both filled and unfilled
b.  flood fills
c.  the use of arbitrary images as brushes and as tiled fill patterns
d.  line styling (dashed lines and the like)
e.  horizontal and vertical text rendering
f.  support for transparency and interlacing

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p0

# Remove Local from path
find . -type f | xargs perl -p -i -e "s|/usr/local/|/usr/|g"

# lib64 fixes, don't add /usr/lib/X11 to linker search path
perl -pi -e "s|-L/usr/lib/X11||g;s|-L/usr/X11/lib||g;s|-L/usr/lib||g" Build.PL
perl -pi -e "s|(/usr/X11R6)/lib|\1/%{_lib}|g" Build.PL

%build
perl Makefile.PL INSTALLDIRS=vendor </dev/null
%make_build

%check
make test

%install
%make_install
find %{buildroot} -type f -name '*.bs' -empty -exec rm -f {} ';'

%files
%doc ChangeLog LICENSE META.json META.yml MYMETA.yml README SIGNATURE demos
%{perl_vendorarch}/GD*
%{perl_vendorarch}/auto/GD*
%{_mandir}/man?/*
%{_bindir}/bdf2gdfont.pl


%changelog
* Fri Dec 01 2023 tv <tv> 2.780.0-3.mga10
+ Revision: 2012029
- Rebuild for perl-5.38

* Thu Nov 30 2023 tv <tv> 2.780.0-2.mga10
+ Revision: 2011544
- Rebuild for perl-5.38

* Sun Sep 10 2023 tv <tv> 2.780.0-1.mga10
+ Revision: 1985777
- update to 2.78

* Tue Jun 07 2022 umeabot <umeabot> 2.760.0-3.mga9
+ Revision: 1861906
- Rebuild for Perl 5.36

* Fri Apr 01 2022 umeabot <umeabot> 2.760.0-2.mga9
+ Revision: 1838143
- Mageia 9 Mass Rebuild

* Wed Feb 02 2022 tv <tv> 2.760.0-1.mga9
+ Revision: 1770988
- update to 2.76

* Fri Jan 28 2022 tv <tv> 2.750.0-1.mga9
+ Revision: 1770086
- update to 2.75

* Tue Jan 25 2022 tv <tv> 2.740.0-1.mga9
+ Revision: 1769705
- update to 2.74

* Mon May 24 2021 umeabot <umeabot> 2.730.0-2.mga9
+ Revision: 1726702
- Rebuild for perl 5.34

* Fri Sep 25 2020 tv <tv> 2.730.0-1.mga8
+ Revision: 1629955
- update to 2.73

* Sun Jul 19 2020 tv <tv> 2.720.0-1.mga8
+ Revision: 1607189
- update to 2.72

* Wed Jun 17 2020 umeabot <umeabot> 2.710.0-5.mga8
+ Revision: 1594799
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 2.710.0-4.mga8
+ Revision: 1529018
- Mageia 8 Mass Rebuild

* Mon Aug 26 2019 tv <tv> 2.710.0-3.mga8
+ Revision: 1432903
- rebuild with perl-5.30

* Fri Feb 15 2019 tv <tv> 2.710.0-2.mga7
+ Revision: 1367318
+ rebuild (emptylog)

* Fri Feb 15 2019 tv <tv> 2.710.0-1.mga7
+ Revision: 1367185
- update to 2.71

* Tue Jan 15 2019 tv <tv> 2.700.0-1.mga7
+ Revision: 1357108
- update to 2.70

* Fri Sep 21 2018 umeabot <umeabot> 2.690.0-2.mga7
+ Revision: 1292920
- Mageia 7 Mass Rebuild

* Mon Aug 27 2018 tv <tv> 2.690.0-1.mga7
+ Revision: 1255033
- update to 2.69

* Mon Aug 06 2018 shlomif <shlomif> 2.680.0-2.mga7
+ Revision: 1248317
- Rebuild for new perl 5.28.0

* Mon Feb 19 2018 tv <tv> 2.680.0-1.mga7
+ Revision: 1202993
- update to 2.68

* Sun Nov 19 2017 tv <tv> 2.670.0-1.mga7
+ Revision: 1177858
- update to 2.67

* Mon Oct 02 2017 tv <tv> 2.660.0-4.mga7
+ Revision: 1164470
- rebuild with fixed rpm for missing autodeps

* Tue Sep 19 2017 tv <tv> 2.660.0-3.mga7
+ Revision: 1155419
- fix build

* Thu Aug 31 2017 pterjan <pterjan> 2.660.0-2.mga7
+ Revision: 1149628
- Rebuild for perl ABI changes

* Sat Jul 22 2017 shlomif <shlomif> 2.660.0-1.mga7
+ Revision: 1128038
- add missing BR
- New version 2.66 + spec modernize

* Sun Jun 19 2016 pterjan <pterjan> 2.560.0-4.mga6
+ Revision: 1027670
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 2.560.0-3.mga6
+ Revision: 957345
- Mageia 6 Mass Rebuild

* Sun Dec 20 2015 tv <tv> 2.560.0-2.mga6
+ Revision: 912690
- patch 1: testsuite fix from FC

* Sun Jun 28 2015 sander85 <sander85> 2.560.0-1.mga6
+ Revision: 847118
- Update to 2.56, sync with Fedora

* Fri Jun 26 2015 tv <tv> 2.530.0-10.mga6
+ Revision: 844874
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 2.530.0-9.mga6
+ Revision: 841120
- Rebuild for the new perl

* Mon Feb 16 2015 oden <oden> 2.530.0-8.mga5
+ Revision: 815161
- rebuilt for libgd-2.1.1

* Wed Oct 15 2014 umeabot <umeabot> 2.530.0-7.mga5
+ Revision: 747881
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 2.530.0-6.mga5
+ Revision: 732183
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 2.530.0-3.mga5
+ Revision: 684811
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 2.530.0-2.mga5
+ Revision: 631206
- Rebuild for perl 5.20

* Fri May 02 2014 sander85 <sander85> 2.530.0-1.mga5
+ Revision: 619688
- update to 2.53

* Mon Feb 24 2014 jquelin <jquelin> 2.520.0-1.mga5
+ Revision: 596262
- update to 2.52

* Mon Feb 10 2014 jquelin <jquelin> 2.510.0-1.mga5
+ Revision: 588407
- update to 2.51

* Mon Oct 21 2013 umeabot <umeabot> 2.500.0-2.mga4
+ Revision: 537211
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 sander85 <sander85> 2.500.0-1.mga4
+ Revision: 486568
- update to 2.50

* Mon Jun 10 2013 jquelin <jquelin> 2.490.0-1.mga4
+ Revision: 441579
- update to 2.49

* Wed May 29 2013 jquelin <jquelin> 2.460.0-7.mga4
+ Revision: 430698
- perl 5.18.0 rebuild

* Wed May 29 2013 tv <tv> 2.460.0-6.mga4
+ Revision: 429985
- rebuild for new perl

* Mon May 27 2013 oden <oden> 2.460.0-5.mga4
+ Revision: 428764
- rebuilt against libgd.so.3

* Sun Jan 13 2013 umeabot <umeabot> 2.460.0-4.mga3
+ Revision: 367523
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 2.460.0-3.mga3
+ Revision: 250643
- rebuild for perl 5.16

* Mon Sep 05 2011 fwang <fwang> 2.460.0-2.mga2
+ Revision: 138591
- rebuild for updated perl build flags

* Fri Jun 17 2011 jquelin <jquelin> 2.460.0-1.mga2
+ Revision: 108866
- update to 2.46

* Sat Jun 11 2011 spuhler <spuhler> 2.450.0-5.mga2
+ Revision: 104068
- increase rel for rebuild

* Thu Jan 27 2011 jquelin <jquelin> 2.450.0-4.mga1
+ Revision: 41926
- skipping tests, one of them fails
- mageia rebuild
- imported package perl-GD
+ shikamaru <shikamaru>
- make the test verbose to see why it fails on BS

